package com.example.flutter_1flow_sdk;

import android.content.Context;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.oneflow.analytics.OneFlow;

import java.util.HashMap;
import java.util.Map;

/**
 * Flutter1flowSdkPlugin
 */
public class Flutter1flowSdkPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context appContext;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flutter_1flow_sdk");
        channel.setMethodCallHandler(this);
        appContext = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("configure")) {
            String projectKey = call.argument("projectKey");
            boolean enableSurveys = call.argument("enableSurveys");
            configure(projectKey, enableSurveys);
            result.success(null);
        } else if (call.method.equals("logUser")) {
            String uniqueId = call.argument("uniqueId");
            Map userDetails = call.argument("userDetails");
            logUser(uniqueId, userDetails);
            result.success(null);
        } else if (call.method.equals("recordEventName")) {
            String eventName = call.argument("eventName");
            Map parameters = call.argument("parameters");
            recordEventName(eventName, parameters);
            result.success(null);
        } else {
            result.notImplemented();
        }
    }

    private void logUser(String uniqueId, Map userDetails) {
        HashMap hashMap = new HashMap(userDetails);
        OneFlow.logUser(uniqueId, hashMap);
    }

    private void recordEventName(String eventName, Map parameters) {
        HashMap hashMap = new HashMap(parameters);
        OneFlow.recordEvents(eventName, hashMap);
    }

    private void configure(String projectKey, boolean enableSurveys) {
        OneFlow.configure(appContext, projectKey);
        OneFlow.shouldShowSurvey(true);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
